Print package information and check dependencies

.onAttach(libname, pkgname)

Arguments

libname

a character string giving the library directory where the package defining the namespace was found.

pkgname

a character string giving the name of the package.