Retrieves the current number of cores configured for parallel computations. If no cores have been set yet, it automatically initializes them by calling setCores().

getCores()

Value

Integer. The number of cores currently configured for parallel processing.

See also

setCores() to configure the number of cores.