Summarize `MSTWeatherGen_Estim()“ function output (swg object class).

# S3 method for class 'swg'
summary(swg, season = NULL, all = FALSE)

Arguments

swg

A swg class, as a list containing the results of the `MSTWeatherGen_Estim` function, including estimated parameters and other outputs relevant to weather generation, such as weather type classifications and spatial dependencies. Each season contains a list containing dates, scale parameters, weather types, transition probabilities, lambda transformations, and parameters for the Gaussian field model for the specified season.

season

vector of seasons names, default NULL show summarize seasons

all

a boolean to output all values as str (default = FALSE)

Value

invisible(NULL)

Examples

if (FALSE) { # \dontrun{
  swg <- MSTWeatherGen_estim()
  summary(swg)
} # }