R/MSTWeatherGen-package.R
getCores.RdRetrieves the current number of cores configured for parallel computations. If no cores have been set yet, it automatically initializes them by calling setCores().
getCores()Integer. The number of cores currently configured for parallel processing.
setCores() to configure the number of cores.