Function to set automatically or manually the number of cores It sets automatically the numbers of core as follows : nb_of_cores available - 2 To change manually you need to call it and put the
setCores(n = NULL)Number of cores set (invisible)
#Automatic setting setCores()
#Manual setting to 4 cores : setCores(4)